import os
from . import env, git, message, cmake

name = "graph"
help = """Show the dependency graph"""
usage = ""
min_args = 0
colors = {}


def color(vendor):
    global colors

    import numpy as np

    if vendor not in colors:
        r, g, b = np.random.randint(100, 255, 3)
        colors[vendor] = "#%02X%02X%02X" % (r, g, b)

    return colors[vendor]


def run(args):
    graph = "digraph {\n"

    for directory in git.get_directories():
        parts = directory.split("/")
        vendor = parts[-2]
        project_name = "/".join(parts[-2:])
        graph += '"%s" [style=filled, color="%s"];\n' % (project_name, color(vendor))

        config = env.get_config(directory)
        if config and "deps" in config:
            for dep in config["deps"]:
                infos = git.parse_repository_name(dep)
                dep_name = "%s/%s" % (infos["vendor"], infos["name"])
                graph += '"%s" -> "%s";\n' % (project_name, dep_name)

    graph += "}\n"

    f = open("/tmp/deps.dot", "w")
    f.write(graph)
    f.close()

    os.system("dot -Tpng /tmp/deps.dot > /tmp/deps.png")
    os.system("eog /tmp/deps.png")



import os
from . import env, git, message, cmake

name = "cmd"
help = """Run a command in all dependencies"""
usage = "[command]"
min_args = 1


def run(args):
    command = " ".join(args)
    for directory in git.get_directories():
        message.bright("* Running command in %s" % directory)
        os.system("cd %s; %s" % (directory, command))



#!/usr/bin/env python

import sys
from . import message, commands, command_help

def main():    
    if len(sys.argv) <= 1:
        command_help.run(sys.argv[2:])
    else:
        for command in commands.commands:
            if command.name == sys.argv[1]:
                if len(sys.argv[2:]) < command.min_args:
                    message.error("Not enough arguments for command " + sys.argv[1])
                    if command.usage:
                        print("Usage: wks " + sys.argv[1] + " " + command.usage)
                else:
                    command.run(sys.argv[2:])
                exit()

        print(message.error("Error: command " + sys.argv[1] + " not found"))
        command_help.run([])

if __name__ == "__main__":
    main()